AuditAssertionError

Enum AuditAssertionError 

pub enum AuditAssertionError {
    MissingResourceCommand {
        context: ResourceAuditContext,
    },
    ResourceCommandMismatch {
        context: ResourceAuditContext,
        field: &'static str,
    },
    MissingOutputFrame {
        context: OutputAuditContext,
    },
    OutputFrameMismatch {
        context: OutputAuditContext,
        field: &'static str,
    },
    MissingDependencyPath {
        from: NodeId,
        to: NodeId,
    },
}
Failure from an explainability assertion over transaction audit data.

Variants



MissingResourceCommand

A resource command had no graph-visible explanation.

Fields

context: ResourceAuditContext

Command context.



ResourceCommandMismatch

A resource command explanation did not match the emitted command.

Fields

context: ResourceAuditContext

Command context.

field: &'static str

Missing or mismatched field name.



MissingOutputFrame

An output frame had no graph-visible explanation.

Fields

context: OutputAuditContext

Frame context.



OutputFrameMismatch

An output frame explanation did not match the emitted frame.

Fields

context: OutputAuditContext

Frame context.

field: &'static str

Missing or mismatched field name.



MissingDependencyPath

A requested dependency path was missing.

Fields

from: NodeId

Upstream node.

to: NodeId

Downstream node.