ResourceLedgerError

Enum ResourceLedgerError 

pub enum ResourceLedgerError {
    Orphan {
        key: ResourceKey,
        context: Option<ResourceCommandContext>,
    },
    DuplicateClose {
        key: ResourceKey,
        context: ResourceCommandContext,
    },
    ForbiddenOpen {
        key: ResourceKey,
        context: Option<ResourceCommandContext>,
    },
    StillOpen {
        key: ResourceKey,
        context: Option<ResourceCommandContext>,
    },
    ClosedScopeOwnsResources {
        scope: ScopeId,
        resources: Vec<ResourceKey>,
        contexts: Vec<ResourceCommandContext>,
    },
    CountMismatch {
        key: ResourceKey,
        field: &'static str,
        expected: usize,
        actual: usize,
        context: Option<ResourceCommandContext>,
    },
    GenerationMismatch {
        key: ResourceKey,
        expected: u64,
        actual: u64,
        context: Option<ResourceCommandContext>,
    },
    OwnerMismatch {
        key: ResourceKey,
        expected: BTreeSet<ScopeId>,
        actual: BTreeSet<ScopeId>,
        context: Option<ResourceCommandContext>,
    },
    CommandOrderMismatch {
        expected: Vec<ResourceCommandTrace>,
        actual: Vec<ResourceCommandTrace>,
    },
    MissingStatus {
        key: ResourceKey,
        command_revision: Revision,
    },
    StatusClassMismatch {
        context: ResourceStatusContext,
        expected: HostStatusClass,
    },
    StatusMutatedClosedScope {
        scope: ScopeId,
        context: ResourceStatusContext,
    },
}
Resource ledger assertion failure.

Variants



Orphan

Resource has no owner.

Fields

key: ResourceKey

Resource key.

context: Option<ResourceCommandContext>

Last known command context for the resource.



DuplicateClose

Resource was closed without a matching owner.

Fields

key: ResourceKey

Resource key.

context: ResourceCommandContext

Command context that attempted the duplicate close.



ForbiddenOpen

Forbidden resource demand was opened.

Fields

key: ResourceKey

Resource key.

context: Option<ResourceCommandContext>

Command context that opened the forbidden resource.



StillOpen

Resource is still open.

Fields

key: ResourceKey

Resource key.

context: Option<ResourceCommandContext>

Last known command context for the resource.



ClosedScopeOwnsResources

A closed scope still owns resources.

Fields

scope: ScopeId

Closed scope.

resources: Vec<ResourceKey>

Resources still owned by the closed scope.

contexts: Vec<ResourceCommandContext>

Last command contexts for the resources.



CountMismatch

Resource command count differed from expectation.

Fields

key: ResourceKey

Resource key.

field: &'static str

Count that differed.

expected: usize

Expected count.

actual: usize

Actual count.

context: Option<ResourceCommandContext>

Last known command context for the resource.



GenerationMismatch

Resource generation differed from expectation.

Fields

key: ResourceKey

Resource key.

expected: u64

Expected generation.

actual: u64

Actual generation.

context: Option<ResourceCommandContext>

Last known command context for the resource.



OwnerMismatch

Resource does not have the expected owners.

Fields

key: ResourceKey

Resource key.

expected: BTreeSet<ScopeId>

Expected owner set.

actual: BTreeSet<ScopeId>

Actual owner set.

context: Option<ResourceCommandContext>

Last known command context for the resource.



CommandOrderMismatch

Resource command order did not match the expected structural trace.

Fields

expected: Vec<ResourceCommandTrace>

Expected command trace.

actual: Vec<ResourceCommandTrace>

Actual command trace.



MissingStatus

No matching status classification was recorded.

Fields

key: ResourceKey

Resource key.

command_revision: Revision

Command revision expected in the status record.



StatusClassMismatch

A status was classified differently than expected.

Fields

context: ResourceStatusContext

Recorded status context.

expected: HostStatusClass

Expected classification.



StatusMutatedClosedScope

A host status appeared to mutate ownership for a closed scope.

Fields

scope: ScopeId

Scope that should remain closed.

context: ResourceStatusContext

Status context that caused the failure.