pub struct ConformanceReport { /* private fields */ }Expand description
Report of supported and unsupported conformance levels.
Implementations
Sourceimpl ConformanceReport
impl ConformanceReport
Sourcepub fn support(self, level: ConformanceLevel) -> Self
pub fn support(self, level: ConformanceLevel) -> Self
Marks a level as supported by the test target.
Sourcepub fn unsupported(self, level: ConformanceLevel) -> Self
pub fn unsupported(self, level: ConformanceLevel) -> Self
Marks a level as explicitly unsupported by the test target.
Sourcepub fn unsupported_with_reason(
self,
level: ConformanceLevel,
reason: impl Into<String>,
) -> Self
pub fn unsupported_with_reason( self, level: ConformanceLevel, reason: impl Into<String>, ) -> Self
Marks a level as explicitly unsupported by the target with a reason.
Sourcepub fn record_check(self, check: ConformanceCheckReport) -> Self
pub fn record_check(self, check: ConformanceCheckReport) -> Self
Records an executed check in this report.
Sourcepub fn supported_levels(&self) -> &BTreeSet<ConformanceLevel>
pub fn supported_levels(&self) -> &BTreeSet<ConformanceLevel>
Returns supported levels.
Sourcepub fn unsupported_levels(&self) -> &BTreeSet<ConformanceLevel>
pub fn unsupported_levels(&self) -> &BTreeSet<ConformanceLevel>
Returns explicitly unsupported levels.
Sourcepub fn unsupported_reasons(&self) -> &BTreeMap<ConformanceLevel, Vec<String>>
pub fn unsupported_reasons(&self) -> &BTreeMap<ConformanceLevel, Vec<String>>
Returns unsupported reasons by conformance level.
Sourcepub fn check_results(&self) -> &[ConformanceCheckReport]
pub fn check_results(&self) -> &[ConformanceCheckReport]
Returns executed check summaries.
Sourcepub fn supports(&self, level: ConformanceLevel) -> bool
pub fn supports(&self, level: ConformanceLevel) -> bool
Returns true if a level is supported.