pub struct FakeHostEvent {
pub status: HostStatusEvent,
pub class: HostStatusClass,
}Expand description
Status event produced by the fake host boundary.
Fields
status: HostStatusEventExplicit event that application tests feed back as canonical input.
class: HostStatusClassLedger classification for the event at the time it was produced.
Implementations
Sourceimpl FakeHostEvent
impl FakeHostEvent
Sourcepub fn into_status(self) -> HostStatusEvent
pub fn into_status(self) -> HostStatusEvent
Consumes the event into the host status application tests feed as input.