pub struct HostStatusRecord {
pub status: HostStatusEvent,
pub class: HostStatusClass,
pub last_transaction_id: Option<TransactionId>,
pub last_command_revision: Option<Revision>,
}Expand description
Recorded classification for a host status event.
Fields
status: HostStatusEventStatus supplied by the fake host.
class: HostStatusClassDeterministic classification assigned by the ledger.
last_transaction_id: Option<TransactionId>Last command transaction known for this resource key, if any.
last_command_revision: Option<Revision>Last command revision known for this resource key, if any.