pub struct SerializedScenario { /* private fields */ }Expand description
A versioned structural trace file for a recorded scenario.
Implementations
Sourceimpl SerializedScenario
impl SerializedScenario
Sourcepub fn from_scenario(scenario: &Scenario) -> Self
pub fn from_scenario(scenario: &Scenario) -> Self
Captures a scenario as a versioned structural trace file.
Sourcepub fn format_version(&self) -> u32
pub fn format_version(&self) -> u32
Returns the serialized format version.
Sourcepub fn steps(&self) -> &[SerializedScenarioStep]
pub fn steps(&self) -> &[SerializedScenarioStep]
Returns trace steps in commit order.
Sourcepub fn into_scenario(self) -> Result<Scenario, ScenarioError>
pub fn into_scenario(self) -> Result<Scenario, ScenarioError>
Rebuilds a scenario recorder from this versioned trace file.
Sourcepub fn assert_matches_scenario(
&self,
actual: &Scenario,
) -> Result<(), ScenarioError>
pub fn assert_matches_scenario( &self, actual: &Scenario, ) -> Result<(), ScenarioError>
Checks this trace file against a freshly replayed scenario.