HostStatusEvent

Type Alias HostStatusEvent 

pub type HostStatusEvent = HostResourceStatus;
Explicit host status event fed to tests after plan application.

Aliased Type

pub struct HostStatusEvent {
    pub resource_key: ResourceKey,
    pub scope: ScopeId,
    pub command_revision: Revision,
    pub status_revision: Revision,
    pub status: HostResourceOutcome,
}

Fields

resource_key: ResourceKey

Stable graph-visible resource identity.

scope: ScopeId

Scope associated with the command being reported.

command_revision: Revision

Graph revision of the resource command the host is reporting for.

status_revision: Revision

Monotonic host observation revision.

status: HostResourceOutcome

Application-defined status payload.