pub enum AuditAssertionError {
MissingResourceCommand {
context: ResourceAuditContext,
},
ResourceCommandMismatch {
context: ResourceAuditContext,
field: &'static str,
},
MissingOutputFrame {
context: OutputAuditContext,
},
OutputFrameMismatch {
context: OutputAuditContext,
field: &'static str,
},
MissingDependencyPath {
from: NodeId,
to: NodeId,
},
}Expand description
Failure from an explainability assertion over transaction audit data.
Variants
MissingResourceCommand
A resource command had no graph-visible explanation.
Fields

context: ResourceAuditContextCommand context.
ResourceCommandMismatch
A resource command explanation did not match the emitted command.
Fields

context: ResourceAuditContextCommand context.
MissingOutputFrame
An output frame had no graph-visible explanation.
Fields

context: OutputAuditContextFrame context.
OutputFrameMismatch
An output frame explanation did not match the emitted frame.
Fields

context: OutputAuditContextFrame context.
MissingDependencyPath
A requested dependency path was missing.