pub struct ConformanceSuite { /* private fields */ }Expand description
Opt-in set of conformance levels an application wants to exercise.
Implementations
Sourceimpl ConformanceSuite
impl ConformanceSuite
Sourcepub fn require(self, level: ConformanceLevel) -> Self
pub fn require(self, level: ConformanceLevel) -> Self
Adds a required level to this suite.
Sourcepub fn required_levels(&self) -> &BTreeSet<ConformanceLevel>
pub fn required_levels(&self) -> &BTreeSet<ConformanceLevel>
Returns required levels.
Sourcepub fn report(&self, supported: &[ConformanceLevel]) -> ConformanceReport
pub fn report(&self, supported: &[ConformanceLevel]) -> ConformanceReport
Builds a report, marking required but unsupported levels explicitly.
Sourcepub fn runner(self) -> ConformanceRunner
pub fn runner(self) -> ConformanceRunner
Creates an executable runner for this conformance suite.