ResourceSnapshot

Struct ResourceSnapshot 

pub struct ResourceSnapshot<C = ()> {
    pub owners: BTreeSet<ScopeId>,
    pub is_open: bool,
    pub open_count: usize,
    pub close_count: usize,
    pub replace_count: usize,
    pub command_revision: Revision,
    pub generation: u64,
    pub last_transaction_id: TransactionId,
    pub last_status_revision: Option<Revision>,
    pub current_command: Option<C>,
    pub injected_status: Option<HostStatusEvent>,
    pub last_command: ResourceCommandRecord<C>,
}
Current or historical ledger view for one resource key.

Fields

owners: BTreeSet<ScopeId>

Scopes that currently own the resource.

is_open: bool

Whether the resource is currently open.

open_count: usize

Number of open commands observed.

close_count: usize

Number of close commands observed.

replace_count: usize

Number of replace commands observed.

command_revision: Revision

Latest command revision observed for this key.

generation: u64

Monotonic command generation assigned by the ledger.

last_transaction_id: TransactionId

Last transaction that emitted a command for this key.

last_status_revision: Option<Revision>

Last accepted host status revision for this key.

current_command: Option<C>

Latest retained host command payload for this key.

injected_status: Option<HostStatusEvent>

Latest injected host status accepted for this key.

last_command: ResourceCommandRecord<C>

Last applied command record for this key.