pub type HostStatusEvent = HostResourceStatus;Expand description
Explicit host status event fed to tests after plan application.
Aliased Type
pub struct HostStatusEvent {
pub resource_key: ResourceKey,
pub scope: ScopeId,
pub command_revision: Revision,
pub status_revision: Revision,
pub status: HostResourceOutcome,
}Fields
resource_key: ResourceKeyStable graph-visible resource identity.
scope: ScopeIdScope associated with the command being reported.
command_revision: RevisionGraph revision of the resource command the host is reporting for.
status_revision: RevisionMonotonic host observation revision.
status: HostResourceOutcomeApplication-defined status payload.